==> roctogen-0.6.0.crate: roctogen-0.6.0/CHANGELOG.md <==
# Changelog

## v0.6.0 (23/05/2021)
- [**closed**] Fix OneOf/AnyOf references in props [#27](https://github.com/fussybeaver/roctogen/pull/27)

---

## v0.5.0 (16/05/2021)
- [**closed**] Update OpenAPI descriptions [#22](https://github.com/fussybeaver/roctogen/pull/22)

---

## v0.4.0 (05/05/2021)
- [**closed**] Do not peg bindgen version [#18](https://github.com/fussybeaver/roctogen/pull/18)

---

## v0.3.0 (25/04/2021)
- [**closed**] Update due to upstream changes [#14](https://github.com/fussybeaver/roctogen/pull/14)
- [**closed**] Tweak README and minor upstream change [#12](https://github.com/fussybeaver/roctogen/pull/12)
- [**closed**] Re-word parts of readme [#10](https://github.com/fussybeaver/roctogen/pull/10)
- [**closed**] Partial impl for one-of/any-of polymorphism [#9](https://github.com/fussybeaver/roctogen/pull/9)
- [**closed**] GitHub update issue bot [#7](https://github.com/fussybeaver/roctogen/pull/7)

---

## v0.2.2 (09/04/2021)
- [**closed**] Allow build without any features [#5](https://github.com/fussybeaver/roctogen/pull/5)

---

## v0.2.1 (09/04/2021)
- [**closed**] Async Isahc, Reqwest and Ureq support [#4](https://github.com/fussybeaver/roctogen/pull/4)

---

## v0.2.0 (03/04/2021)
- [**closed**] Add JWT auth mechanism [#3](https://github.com/fussybeaver/roctogen/pull/3)

---

## v0.1.2 (22/03/2021)
- [**closed**] Add wiremock and github action [#2](https://github.com/fussybeaver/roctogen/pull/2)

---

## v0.1.1 (16/03/2021)
- [**closed**] Fix GitHub API links [#1](https://github.com/fussybeaver/roctogen/pull/1)

---

## v0.1.0 (14/03/2021)
*No changelog for this release.*

==> roctogen-0.9.0.crate: roctogen-0.9.0/CHANGELOG.md <==
# Changelog

## v0.9.0 (03/08/2021)
- [**closed**] Update from upstream [#43](https://github.com/fussybeaver/roctogen/pull/43)

---

## v0.8.0 (12/07/2021)
- [**closed**] Update from upstream changes [#37](https://github.com/fussybeaver/roctogen/pull/37)

---

## v0.7.0 (20/06/2021)
- [**closed**] Update upstream openapi changes [#32](https://github.com/fussybeaver/roctogen/pull/32)

---

## v0.6.0 (23/05/2021)
- [**closed**] Fix OneOf/AnyOf references in props [#27](https://github.com/fussybeaver/roctogen/pull/27)

---

## v0.5.0 (16/05/2021)
- [**closed**] Update OpenAPI descriptions [#22](https://github.com/fussybeaver/roctogen/pull/22)

---

## v0.4.0 (05/05/2021)
- [**closed**] Do not peg bindgen version [#18](https://github.com/fussybeaver/roctogen/pull/18)

---

## v0.3.0 (25/04/2021)
- [**closed**] Update due to upstream changes [#14](https://github.com/fussybeaver/roctogen/pull/14)
- [**closed**] Tweak README and minor upstream change [#12](https://github.com/fussybeaver/roctogen/pull/12)
- [**closed**] Re-word parts of readme [#10](https://github.com/fussybeaver/roctogen/pull/10)
- [**closed**] Partial impl for one-of/any-of polymorphism [#9](https://github.com/fussybeaver/roctogen/pull/9)
- [**closed**] GitHub update issue bot [#7](https://github.com/fussybeaver/roctogen/pull/7)

---

## v0.2.2 (09/04/2021)
- [**closed**] Allow build without any features [#5](https://github.com/fussybeaver/roctogen/pull/5)

---

## v0.2.1 (09/04/2021)
- [**closed**] Async Isahc, Reqwest and Ureq support [#4](https://github.com/fussybeaver/roctogen/pull/4)

---

## v0.2.0 (03/04/2021)
- [**closed**] Add JWT auth mechanism [#3](https://github.com/fussybeaver/roctogen/pull/3)

---

## v0.1.2 (22/03/2021)
- [**closed**] Add wiremock and github action [#2](https://github.com/fussybeaver/roctogen/pull/2)

---

## v0.1.1 (16/03/2021)
- [**closed**] Fix GitHub API links [#1](https://github.com/fussybeaver/roctogen/pull/1)

---

## v0.1.0 (14/03/2021)
*No changelog for this release.*
